@@ -49,9 +49,11 @@ def replicate_acl_for(database, old_ip, new_ip, old_sa=None, new_sa=None):
                 try:
                     copy_acl_rule(rule, destinations[d], acl,
                                   database, new_sa)
-                    LOG.info("Rule copied: {}".format(rule))
+                    LOG.info("Rule {} copied to {}".format(
+                        rule, destinations[d]))
                 except Exception as e:
-                    error = "Rule could not be copied: {}. {}".format(rule, e)
+                    error = "Rule {} could not be copied to {}. {}".format(
+                        rule, destinations[d], e)
                     LOG.warn(error)
                     raise Exception(error)
 
